<?php
/*
 * copyright (c) 2009 MDBitz - Matthew John Denton - mdbitz.com
 *
 * This file is part of HarvestAPI.
 *
 * HarvestAPI is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HarvestAPI is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HarvestAPI. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * Filter
 *
 * This file contains the class Harvest_Invoice_Filter
 *
 * @author Matthew John Denton <matt@mdbitz.com>
 * @version 0.1
 * @package com.mdbitz.harvest
 */

/**
 * Harvest Invoice Filter Object
 *
 * @package com.mdbitz.harvest
 */
class Harvest_Invoice_Filter {

	/**
	 * Status : "open"
	 */
	const OPEN                       = "open";

    /**
	 * Status : "partial"
	 */
	const PARTIAL                    = "partial";

    /**
	 * Status : "draft"
	 */
	const DRAFT                      = "draft";

    /**
	 * Status : "paid"
	 */
	const PAID                       = "paid";

    /**
	 * Status : "unpaid"
	 */
	const UNPAID                     = "unpaid";

    /**
	 * Status : "pastdue"
	 */
	const PASTDUE                    = "pastdue";

    /**
     * @var Harvest_Range $_range
     */
    protected $_range = null;

	/**
     * @var integer $_page
     */
    protected $_page = null;

	/**
     * @var string $_status
     */
    protected $_status = null;

	/**
     * @var integer $_client
     */
    protected $_client = null;

    /**
	 * get specifed property
	 *
	 * @param $mixed $property
	 */
	public function get( $property )
    {
        switch( $property ) {
			case 'range':
				return $this->_range;
			break;
			case 'page':
				return $this->_page;
			break;
			case 'status':
				return $this->_status;
			break;
			case 'client':
				return $this->_client;
			break;
			default:
				throw new Harvest_Exception( sprintf('Unknown method %s::%s', get_class($this), $method));
			break;
		}
		
	}
	
	/**
	 * set property to specified value
	 *
	 * @param mixed $property
	 * @param mixed $value
	 */
	public function set( $property, $value ) 
	{
		switch( $property ) {
			case 'range':
				$this->_range = $value;
			break;
			case 'page':
				$this->_page = $value;
			break;
			case 'status':
				$this->_status = $value;
			break;
			case 'client':
				$this->_client = $value;
			break;
			default:
				throw new Harvest_Exception( sprintf('Unknown method %s::%s', get_class($this), $method));
			break;
		}
	}

	/**
     * magic method used for method overloading
     *
     * @param string $method        name of the method
     * @param array $args           method arguments
     * @return mixed                the return value of the given method
     */
    public function __call($method, $arguments)
    {
    	if( count($arguments) == 0 ) {
			return $this->get( $method );
		} else if( count( $arguments ) == 1 ) {
			return $this->set( $method, $arguments[0] );
		}
		
		throw new Harvest_Exception( sprintf('Unknown method %s::%s', get_class($this), $method));
    }

    /**
     * returns generated url for use in api call
     *
     * @return String query uri
     */
    public function toURL()
	{
		$query = "";
		if( ! is_null( $this->_page ) ){
			$query .= "&page=" . $this->_page;
		} 
		if( ! is_null( $this->_client ) ) {
			$query .= "&client=" . $this->_client;
		}
		if( ! is_null( $this->_status ) ) {
			$query .= "&status=". $this->_status;
		}
		if( ! is_null( $this->_range ) ) {
			$query .= "&from=" . $this->_range->from() . "&to=" . $this->_range->to();
		}
		
		$query = "?" . substr( $query, 1 );
		return $query;
	}
	
}