<?php
/*
 * copyright (c) 2009 MDBitz - Matthew John Denton - mdbitz.com
 *
 * This file is part of HarvestAPI.
 *
 * HarvestAPI is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HarvestAPI is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HarvestAPI. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * Project
 *
 * This file contains the class Harvest_Project
 *
 * @author Matthew John Denton <matt@mdbitz.com>
 * @version 0.1
 * @package com.mdbitz.harvest
 */

/**
 * Harvest Project Object
 *
 * @package com.mdbitz.harvest
 */
class Harvest_Project extends Harvest_Abstract {
	
	/**
     * @var Array of Harvest_Tasks
     */
    protected $_tasks = null;

	/**
	* get all tasks
	*
	* @return array of Harvest_Task objects @see $_tasks
	*/
	public function tasks() 
	{
		return $this->_tasks;
	}

	/**
     * parse XML represenation into a Harvest DailyActivity object
     *
     * @param XMLNode $node        xml node to parse
     * @return Abstract            
     */
	public function parseXML( $node ) {
		
		foreach ( $node->childNodes as $item ) {
			switch( $item->nodeName ) 
			{	
				case "#text":
				break;
				case "tasks":
					$this->_tasks = $this->parseItems( $item );
				break;
				default:
					$this->set( $item->nodeName, $item->nodeValue);
				break;
			}
		}
		
	}
	
	/**
	 * parse xml list
	 * @param string $xml
	 * @return array of items
	 */
	private function parseItems( $xml ) {
		$items = array();
		
		foreach ($xml->childNodes AS $item)
		{
			$item = $this->parseNode( $item );
			if( ! is_null( $item ) ) 
			{
				$items[$item->id()] = $item;
			}
		}
		
		return $items;
		
	}
	
	/**
	 * parse xml node
	 * @param documentElement $node
	 * @return object
	 */
	private function parseNode( $node ) {
		$item = null;
		
		switch( $node->nodeName ) 
		{	
			case "task":
				$item = new Harvest_Task();
			break;
			default:
			break;
		}
		if( ! is_null( $item ) ) {
			$item->parseXML( $node );
		}
		
		return $item;
		
	}
	
}