<?php
/*
 * copyright (c) 2009 MDBitz - Matthew John Denton - mdbitz.com
 *
 * This file is part of HarvestAPI.
 *
 * HarvestAPI is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HarvestAPI is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HarvestAPI. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * Result
 *
 * This file contains the class Harvest_Result
 *
 * @author Matthew John Denton <matt@mdbitz.com>
 * @version 0.1
 * @package com.mdbitz.harvest
 */

/**
 * Harvest Result Object
 *
 * @package com.mdbitz.harvest
 */
class Harvest_Result
{

    /**
     * response code
     *
     * @access protected
     * @var string
     */
    protected $_code = null;

    /**
     * response data
     *
     * @access protected
     * @var array
     */
    protected $_data = null;

    /**
     * Constructor initializes {@link $_code} {@link $_data}
     *
     * @param string $code response code
     * @param array $data array of Quote Objects
     */
    public function __construct( $code = null, $data = null)
    {
        $this->_code = $code;
        $this->_data = $data;
    }

    /**
     * magic method to return non public properties
     *
     * @see     get
     * @param   mixed $property
     * @return  mixed
     */
    public function __get( $property )
    {
        return $this->get( $property);
    }

    /**
     * Return the specified property
     *
     * @param mixed $property     The property to return
     * @return mixed
     */
    public function get( $property )
    {
        switch( $property ){
            case 'code':
                return $this->_code;
            break;
            case 'data':
                return $this->_data;
            break;
            default:
                throw new YahooFinance_Exception(sprintf('Unknown property %s::%s', get_class($this), $property));
            break;
        }
    }

    /**
     * magic method to set non public properties
     *
     * @see    set
     * @param  mixed $property
     * @param  mixed $value
     */
    public function __set( $property, $value )
    {
        $this->set( $property, $value );
    }

    /**
     * sets the specified property
     *
     * @param mixed $property     The property to set
     * @param mixed $value        value of property
     */
    public function set( $property, $value )
    {
        switch( $property ){
            case 'code':
                $this->_code = $value;
            break;
            case 'data':
                $this->_data = $value;
            break;
            default:
                throw new YahooFinance_Exception(sprintf('Unknown property %s::%s', get_class($this), $property));
            break;
        }
    }

    /**
     * is request successfull
     */
    public function isSuccess() 
    {
        if( "2" == substr( $code, 0, 1 ) ) {
            return true;
        } else {
            return false;
        }
    }

}